@@ -19,9 +19,12 @@ OC.L10N.register(
     "Uploading …" : "Wysyłanie...",
     "…" : "...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
+    "Target folder does not exist any more" : "Folder docelowy już nie istnieje",
+    "Error when assembling chunks, status code {status}" : "Błąd podczas łączenia fragmentów, kod statusu {status}",
     "Actions" : "Akcje",
     "Download" : "Pobierz",
     "Rename" : "Zmień nazwę",
+    "Move or copy" : "Przenieś lub kopiuj",
     "Target folder" : "Folder docelowy",
     "Delete" : "Usuń",
     "Disconnect storage" : "Odłącz magazyn",
@@ -36,6 +39,10 @@ OC.L10N.register(
     "This directory is unavailable, please check the logs or contact the administrator" : "Ten folder jest niedostępny, proszę sprawdzić logi lub skontaktować się z administratorem.",
     "Could not move \"{file}\", target exists" : "Nie można przenieść „{file}” - plik o takiej nazwie już istnieje",
     "Could not move \"{file}\"" : "Nie można przenieść \"{file}\"",
+    "Could not copy \"{file}\", target exists" : "Nie można skopiować \"{file}\", plik już istnieje",
+    "Could not copy \"{file}\"" : "Nie można skopiować \"{file}\"",
+    "Copied {origin} inside {destination}" : "Skopiowano {origin} wewnątrz {destination}",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "Skopiowano {origin} oraz {nbfiles} innych plików wewnątrz {destination}",
     "{newName} already exists" : "{newName} już istnieje",
     "Could not rename \"{fileName}\", it does not exist any more" : "Nie można zmienić nazwy \"{fileName}\", plik nie istnieje",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{targetName}\" jest juz używana w folderze \"{dir}\". Proszę wybrać inną nazwę.",
@@ -72,6 +79,9 @@ OC.L10N.register(
     "Favorite" : "Ulubione",
     "New folder" : "Nowy folder",
     "Upload file" : "Wyślij plik",
+    "Not favorited" : "Wyłączone z ulubionych",
+    "Remove from favorites" : "Usuń z ulubionych",
+    "Add to favorites" : "Dodaj do ulubionych",
     "An error occurred while trying to update the tags" : "Wystąpił błąd podczas aktualizacji tagów",
     "Added to favorites" : "Dodano do ulubionych",
     "Removed from favorites" : "Usunięto z ulubionych",
@@ -117,8 +127,8 @@ OC.L10N.register(
     "Settings" : "Ustawienia",
     "Show hidden files" : "Pokaż ukryte pliki",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Użyj tego adresu aby uzyskać <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dostęp do swoich plików poprzez WebDAV</a>",
-    "Uploading @" : "Wysyłanie",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Użyj tego adresu aby uzyskać <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dostęp do swoich plików poprzez WebDAV</a>",
+    "Cancel upload" : "Anuluj wysyłanie",
     "No files in here" : "Brak plików",
     "Upload some content or sync with your devices!" : "Wgraj coś, albo wykonaj synchronizację ze swoimi urządzeniami.",
     "No entries found in this folder" : "Brak wpisów w tym folderze",
@@ -151,6 +161,7 @@ OC.L10N.register(
     "Upload" : "Wyślij",
     "A new file or folder has been <strong>deleted</strong>" : "Nowy plik lub folder został <strong>usunięty </strong>",
     "A new file or folder has been <strong>restored</strong>" : "Nowy plik lub folder został <strong>przywrócony</strong>",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Użyj tego adresu aby uzyskać <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dostęp do swoich plików poprzez WebDAV</a>",
     "No favorites" : "Brak ulubionych"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
