@@ -188,6 +188,71 @@ describe('Core base tests', function() {
 			expect(OC.joinPaths('/', '//', '/')).toEqual('/');
 		});
 	});
+	describe('isSamePath', function() {
+		it('recognizes empty paths are equal', function() {
+			expect(OC.isSamePath('', '')).toEqual(true);
+			expect(OC.isSamePath('/', '')).toEqual(true);
+			expect(OC.isSamePath('//', '')).toEqual(true);
+			expect(OC.isSamePath('/', '/')).toEqual(true);
+			expect(OC.isSamePath('/', '//')).toEqual(true);
+		});
+		it('recognizes path with single sections as equal regardless of extra slashes', function() {
+			expect(OC.isSamePath('abc', 'abc')).toEqual(true);
+			expect(OC.isSamePath('/abc', 'abc')).toEqual(true);
+			expect(OC.isSamePath('//abc', 'abc')).toEqual(true);
+			expect(OC.isSamePath('abc', '/abc')).toEqual(true);
+			expect(OC.isSamePath('abc/', 'abc')).toEqual(true);
+			expect(OC.isSamePath('abc/', 'abc/')).toEqual(true);
+			expect(OC.isSamePath('/abc/', 'abc/')).toEqual(true);
+			expect(OC.isSamePath('/abc/', '/abc/')).toEqual(true);
+			expect(OC.isSamePath('//abc/', '/abc/')).toEqual(true);
+			expect(OC.isSamePath('//abc//', '/abc/')).toEqual(true);
+
+			expect(OC.isSamePath('abc', 'def')).toEqual(false);
+			expect(OC.isSamePath('/abc', 'def')).toEqual(false);
+			expect(OC.isSamePath('//abc', 'def')).toEqual(false);
+			expect(OC.isSamePath('abc', '/def')).toEqual(false);
+			expect(OC.isSamePath('abc/', 'def')).toEqual(false);
+			expect(OC.isSamePath('abc/', 'def/')).toEqual(false);
+			expect(OC.isSamePath('/abc/', 'def/')).toEqual(false);
+			expect(OC.isSamePath('/abc/', '/def/')).toEqual(false);
+			expect(OC.isSamePath('//abc/', '/def/')).toEqual(false);
+			expect(OC.isSamePath('//abc//', '/def/')).toEqual(false);
+		});
+		it('recognizes path with multiple sections as equal regardless of extra slashes', function() {
+			expect(OC.isSamePath('abc/def', 'abc/def')).toEqual(true);
+			expect(OC.isSamePath('/abc/def', 'abc/def')).toEqual(true);
+			expect(OC.isSamePath('abc/def', '/abc/def')).toEqual(true);
+			expect(OC.isSamePath('abc/def/', '/abc/def/')).toEqual(true);
+			expect(OC.isSamePath('/abc/def/', '/abc/def/')).toEqual(true);
+			expect(OC.isSamePath('/abc/def/', 'abc/def/')).toEqual(true);
+			expect(OC.isSamePath('//abc/def/', 'abc/def/')).toEqual(true);
+			expect(OC.isSamePath('//abc/def//', 'abc/def/')).toEqual(true);
+
+			expect(OC.isSamePath('abc/def', 'abc/ghi')).toEqual(false);
+			expect(OC.isSamePath('/abc/def', 'abc/ghi')).toEqual(false);
+			expect(OC.isSamePath('abc/def', '/abc/ghi')).toEqual(false);
+			expect(OC.isSamePath('abc/def/', '/abc/ghi/')).toEqual(false);
+			expect(OC.isSamePath('/abc/def/', '/abc/ghi/')).toEqual(false);
+			expect(OC.isSamePath('/abc/def/', 'abc/ghi/')).toEqual(false);
+			expect(OC.isSamePath('//abc/def/', 'abc/ghi/')).toEqual(false);
+			expect(OC.isSamePath('//abc/def//', 'abc/ghi/')).toEqual(false);
+		});
+		it('recognizes path entries with dot', function() {
+			expect(OC.isSamePath('.', '')).toEqual(true);
+			expect(OC.isSamePath('.', '.')).toEqual(true);
+			expect(OC.isSamePath('.', '/')).toEqual(true);
+			expect(OC.isSamePath('/.', '/')).toEqual(true);
+			expect(OC.isSamePath('/./', '/')).toEqual(true);
+			expect(OC.isSamePath('/./', '/.')).toEqual(true);
+			expect(OC.isSamePath('/./', '/./')).toEqual(true);
+			expect(OC.isSamePath('/./', '/./')).toEqual(true);
+
+			expect(OC.isSamePath('a/./b', 'a/b')).toEqual(true);
+			expect(OC.isSamePath('a/b/.', 'a/b')).toEqual(true);
+			expect(OC.isSamePath('./a/b', 'a/b')).toEqual(true);
+		});
+	});
 	describe('filePath', function() {
 		beforeEach(function() {
 			OC.webroot = 'http://localhost';
@@ -525,6 +590,56 @@ describe('Core base tests', function() {
 				}
 			});
 		});
+		describe('computerFileSize', function() {
+			it('correctly parses file sizes from a human readable formated string', function() {
+				var data = [
+					['125', 125],
+					['125.25', 125],
+					['125.25B', 125],
+					['125.25 B', 125],
+					['0 B', 0],
+					['99999999999999999999999999999999999999999999 B', 99999999999999999999999999999999999999999999],
+					['0 MB', 0],
+					['0 kB', 0],
+					['0kB', 0],
+					['125 B', 125],
+					['125b', 125],
+					['125 KB', 128000],
+					['125kb', 128000],
+					['122.1 MB', 128031130],
+					['122.1mb', 128031130],
+					['119.2 GB', 127990025421],
+					['119.2gb', 127990025421],
+					['116.4 TB', 127983153473126],
+					['116.4tb', 127983153473126],
+					['8776656778888777655.4tb', 9.650036181387265e+30],
+					[1234, null],
+					[-1234, null],
+					['-1234 B', null],
+					['B', null],
+					['40/0', null],
+					['40,30 kb', null],
+					[' 122.1 MB ', 128031130],
+					['122.1 MB ', 128031130],
+					[' 122.1 MB ', 128031130],
+					['	122.1 MB ', 128031130],
+					['122.1    MB ', 128031130],
+					[' 125', 125],
+					[' 125 ', 125],
+				];
+				for (var i = 0; i < data.length; i++) {
+					expect(OC.Util.computerFileSize(data[i][0])).toEqual(data[i][1]);
+				}
+			});
+			it('returns null if the parameter is not a string', function() {
+				expect(OC.Util.computerFileSize(NaN)).toEqual(null);
+				expect(OC.Util.computerFileSize(125)).toEqual(null);
+			});
+			it('returns null if the string is unparsable', function() {
+				expect(OC.Util.computerFileSize('')).toEqual(null);
+				expect(OC.Util.computerFileSize('foobar')).toEqual(null);
+			});
+		});
 		describe('stripTime', function() {
 			it('strips time from dates', function() {
 				expect(OC.Util.stripTime(new Date(2014, 2, 24, 15, 4, 45, 24)))
@@ -872,8 +987,9 @@ describe('Core base tests', function() {
 			fadeOutStub.restore();
 		});
 		it('hides the first notification when calling hide without arguments', function() {
-			var $row1 = OC.Notification.show('One');
+			OC.Notification.show('One');
 			var $row2 = OC.Notification.show('Two');
+			spyOn(console, 'warn');
 
 			var $el = $('#notification');
 			var $rows = $el.find('.row');
@@ -881,6 +997,7 @@ describe('Core base tests', function() {
 
 			OC.Notification.hide();
 
+			expect(console.warn).toHaveBeenCalled();
 			$rows = $el.find('.row');
 			expect($rows.length).toEqual(1);
 			expect($rows.eq(0).is($row2)).toEqual(true);
@@ -903,9 +1020,12 @@ describe('Core base tests', function() {
 	describe('global ajax errors', function() {
 		var reloadStub, ajaxErrorStub, clock;
 		var notificationStub;
-		var waitTimeMs = 6000;
+		var waitTimeMs = 6500;
+		var oldCurrentUser;
 
 		beforeEach(function() {
+			oldCurrentUser = OC.currentUser;
+			OC.currentUser = 'dummy';
 			clock = sinon.useFakeTimers();
 			reloadStub = sinon.stub(OC, 'reload');
 			notificationStub = sinon.stub(OC.Notification, 'show');
@@ -915,6 +1035,7 @@ describe('Core base tests', function() {
 			window.initCore();
 		});
 		afterEach(function() {
+			OC.currentUser = oldCurrentUser;
 			reloadStub.restore();
 			notificationStub.restore();
 			clock.restore();
@@ -924,7 +1045,7 @@ describe('Core base tests', function() {
 			var dataProvider = [
 				[200, false],
 				[400, false],
-				[0, true],
+				[0, false],
 				[401, true],
 				[302, true],
 				[303, true],
@@ -974,10 +1095,21 @@ describe('Core base tests', function() {
 		it('displays notification', function() {
 			var xhr = { status: 401 };
 
+			notificationUpdateStub = sinon.stub(OC.Notification, 'showUpdate');
+
 			$(document).trigger(new $.Event('ajaxError'), xhr);
 
 			clock.tick(waitTimeMs);
-			expect(notificationStub.calledOnce).toEqual(true);
+			expect(notificationUpdateStub.notCalled).toEqual(false);
+		});
+		it('shows a temporary notification if the connection is lost', function() {
+			var xhr = { status: 0 };
+			spyOn(OC, '_ajaxConnectionLostHandler');
+
+			$(document).trigger(new $.Event('ajaxError'), xhr);
+			clock.tick(101);
+
+			expect(OC._ajaxConnectionLostHandler.calls.count()).toBe(1);
 		});
 	});
 });
