@@ -1,16 +1,25 @@
 OC.L10N.register(
     "settings",
     {
-    "Enabled" : "활성",
-    "Not enabled" : "비활성",
+    "{actor} changed your password" : "{actor} 님이 내 암호를 변경함",
+    "You changed your password" : "내 암호를 변경함",
+    "Your password was reset by an administrator" : "관리자가 내 암호를 초기화함",
+    "{actor} changed your email address" : "{actor} 님이 내 이메일 주소를 변경함",
+    "You changed your email address" : "내 이메일 주소를 변경함",
+    "Your email address was changed by an administrator" : "관리자가 내 이메일 주소를 변경함",
+    "Your <strong>password</strong> or <strong>email</strong> was modified" : "내 <strong>암호</strong> 및 <strong>이메일</strong>이 변경됨",
+    "Your apps" : "내 앱",
+    "Enabled apps" : "활성화된 앱",
+    "Disabled apps" : "비활성화된 앱",
+    "App bundles" : "앱 번들",
     "Wrong password" : "잘못된 암호",
     "Saved" : "저장됨",
     "No user supplied" : "사용자가 지정되지 않음",
     "Unable to change password" : "암호를 변경할 수 없음",
     "Authentication error" : "인증 오류",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "관리자 복구 암호를 입력하지 않으면 모든 사용자 데이터가 삭제됩니다",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "관리자 복구 암호를 입력하십시오. 그렇지 않으면 모든 사용자 데이이터가 초기화됩니다다.",
     "Wrong admin recovery password. Please check the password and try again." : "관리자 복구 암호가 잘못되었습니다. 암호를 다시 확인하십시오.",
-    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "백엔드에서 암호 변경을 지원하지 않지만, 암호화 키는 갱신되었습니다.",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "백엔드에서 암호 변경을 지원하지 않지만 사용자의 암호화 키는 업데이트되었습니다.",
     "installing and updating apps via the app store or Federated Cloud Sharing" : "앱 스토어 및 연합 클라우드 공유로 앱 설치 및 업데이트",
     "Federated Cloud Sharing" : "클라우드 연합 공유",
     "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL이 오래된 %s 버전을 사용하고 있습니다(%s). 운영 체제나 기능을 업데이트하지 않으면 %s 등을 안정적으로 사용할 수 없습니다.",
@@ -19,76 +28,121 @@ OC.L10N.register(
     "Group already exists." : "그룹이 이미 존재합니다.",
     "Unable to add group." : "그룹을 추가할 수 없습니다.",
     "Unable to delete group." : "그룹을 삭제할 수 없습니다.",
-    "test email settings" : "이메일 설정 시험",
+    "Invalid SMTP password." : "SMTP 암호가 잘못되었습니다.",
+    "Email setting test" : "이메일 설정 시험",
+    "Well done, %s!" : "%s 님, 잘 하셨습니다!",
+    "If you received this email, the email configuration seems to be correct." : "이 이메일을 받으셨다면 이메일 설정이 올바릅니다.",
+    "Email could not be sent. Check your mail server log" : "이메일을 보낼 수 없습니다. 메일 서버 로그를 확인하십시오.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "이메일을 보내는 중 오류가 발생했습니다. 설정을 확인하십시오.(오류: %s)",
-    "Email sent" : "이메일 발송됨",
     "You need to set your user email before being able to send test emails." : "테스트 이메일을 보내기 전 내 주소를 설정해야 합니다.",
-    "Invalid request" : "잘못된 요청",
     "Invalid mail address" : "잘못된 이메일 주소",
+    "No valid group selected" : "올바른 그룹을 선택하지 않았음",
     "A user with that name already exists." : "같은 이름의 사용자가 이미 존재합니다.",
+    "To send a password link to the user an email address is required." : "사용자에게 암호 링크를 보내려면 이메일 주소가 필요합니다.",
     "Unable to create user." : "사용자를 만들 수 없습니다.",
-    "Your %s account was created" : "%s 계정을 등록했습니다",
     "Unable to delete user." : "사용자를 삭제할 수 없습니다.",
+    "Error while enabling user." : "사용자를 활성화할 수 없습니다.",
+    "Error while disabling user." : "사용자를 비활성화할 수 없습니다.",
+    "Settings saved" : "설정 저장됨",
     "Unable to change full name" : "전체 이름을 변경할 수 없음",
+    "Unable to change email address" : "이메일 주소를 변경할 수 없음",
     "Your full name has been changed." : "전체 이름이 변경되었습니다.",
     "Forbidden" : "거부됨",
     "Invalid user" : "잘못된 사용자",
     "Unable to change mail address" : "이메일 주소를 변경할 수 없음",
     "Email saved" : "이메일 저장됨",
+    "%1$s changed your password on %2$s." : "%1$s 님이 내 암호를 %2$s에 변경했습니다.",
+    "Your password on %s was changed." : "내 %s 암호를 변경했습니다.",
+    "Your password on %s was reset by an administrator." : "관리자가 내 %s 암호를 초기화했습니다.",
+    "Password for %1$s changed on %2$s" : "%1$s의 암호를 %2$s에 변경함",
+    "Password changed for %s" : "%s의 암호 변경됨",
+    "If you did not request this, please contact an administrator." : "요청하지 않았다면 관리자에게 연락하십시오.",
+    "%1$s changed your email address on %2$s." : "%1$s 님이 내 이메일 주소를 %2$s에 변경했습니다.",
+    "Your email address on %s was changed." : "내 %s 이메일 주소를 변경했습니다.",
+    "Your email address on %s was changed by an administrator." : "관리자가 내 %s 이메일 주소를 변경했습니다.",
+    "Email address for %1$s changed on %2$s" : "%1$s의 이메일 주소를 %2$s에 변경함",
+    "Email address changed for %s" : "%s의 이메일 주소 변경됨",
+    "The new email address is %s" : "새 이메일 주소는 %s입니다",
+    "Your %s account was created" : "%s 계정을 등록했습니다",
+    "Welcome aboard" : "환영합니다",
+    "Welcome aboard %s" : "%s 님, 환영합니다",
+    "Your username is: %s" : "사용자 이름: %s",
+    "Set your password" : "내 암호 설정하기",
+    "Go to %s" : "%s(으)로 이동",
+    "Install Client" : "클라이언트 설치",
+    "Password confirmation is required" : "암호 확인이 필요합니다",
     "Couldn't remove app." : "앱을 삭제할 수 없습니다.",
-    "Admins can't remove themself from the admin group" : "관리자 자신을 관리자 그룹에서 삭제할 수 없음",
-    "Unable to add user to group %s" : "그룹 %s에 사용자를 추가할 수 없음",
-    "Unable to remove user from group %s" : "그룹 %s에서 사용자를 삭제할 수 없음",
     "Couldn't update app." : "앱을 업데이트할 수 없습니다.",
+    "Are you really sure you want add {domain} as trusted domain?" : "신뢰할 수 있는 도메인 목록에 {domain}을(를) 추가하시겠습니까?",
     "Add trusted domain" : "신뢰할 수 있는 도메인 추가",
     "Migration in progress. Please wait until the migration is finished" : "이전 작업 중입니다. 작업이 완료될 때까지 기다려 주십시오",
     "Migration started …" : "이전 시작됨...",
     "Not saved" : "저장하지 않음",
-    "Sending..." : "보내는 중...",
+    "Sending…" : "보내는 중…",
+    "Email sent" : "이메일 보냄",
     "Official" : "공식",
     "All" : "모두",
     "Update to %s" : "%s(으)로 업데이트",
-    "_You have %n app update pending_::_You have %n app updates pending_" : ["앱 %n개 업데이트 대기 중"],
     "No apps found for your version" : "설치된 버전에 대한 앱 없음",
-    "The app will be downloaded from the app store" : "이 앱은 앱 스토어에서 다운로드 할 것",
+    "The app will be downloaded from the app store" : "이 앱을 앱 스토어에서 다운로드합니다",
+    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "커뮤니티가 개발한 공식 앱입니다. 이 앱은 Nextcloud의 핵심 기능이며 프로덕션 환경에서 사용할 수 있습니다.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "승인된 앱은 신뢰할 수 있는 개발자가 개발하며 보안 검사를 통과했습니다. 열린 코드 저장소에서 관리되며 일반적인 환경에서 사용할 수 있는 수준으로 관리됩니다.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "이 앱의 보안 문제가 점검되지 않았고, 출시된 지 얼마 지나지 않았거나 아직 불안정합니다. 본인 책임 하에 설치하십시오.",
-    "Please wait...." : "기다려 주십시오....",
+    "Disabling app …" : "앱 비활성화 중 …",
     "Error while disabling app" : "앱을 비활성화하는 중 오류 발생",
     "Disable" : "사용 안함",
     "Enable" : "사용함",
+    "Enabling app …" : "앱 활성화 중 …",
     "Error while enabling app" : "앱을 활성화하는 중 오류 발생",
-    "Error: this app cannot be enabled because it makes the server unstable" : "오류: 이 앱은 서버를 불안정하게 만들 수 있어서 활성화할 수 없습니다",
-    "Error: could not disable broken app" : "오류: 망가진 앱을 비활성화할 수 없음",
     "Error while disabling broken app" : "망가진 앱을 비활성화 하는 중 오류 발생",
     "Updating...." : "업데이트 중....",
     "Error while updating app" : "앱을 업데이트하는 중 오류 발생",
     "Updated" : "업데이트됨",
-    "Uninstalling ...." : "제거 하는 중 ....",
-    "Error while uninstalling app" : "앱을 제거하는 중 오류 발생",
-    "Uninstall" : "제거",
+    "Removing …" : "삭제 중 …",
+    "Error while removing app" : "앱을 삭제하는 중 오류 발생",
+    "Remove" : "삭제",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "앱이 활성화되었지만, 앱을 업데이트해야 합니다. 5초 후 앱 업데이트 페이지로 넘어갑니다.",
     "App update" : "앱 업데이트",
     "Approved" : "승인됨",
     "Experimental" : "실험적",
+    "No apps found for {query}" : "{query} 앱을 찾을 수 없음",
+    "Enable all" : "모두 활성화",
+    "Allow filesystem access" : "파일시스템 접근 허용",
     "Disconnect" : "연결 해제",
-    "Internet Explorer" : "인터넷 익스플로러",
-    "Edge" : "엣지",
-    "Firefox" : "파이어 폭스",
-    "Google Chrome" : "구글 크롬",
-    "Safari" : "사파리",
-    "Google Chrome for Android" : "안드로이드 용 구글 크롬",
-    "iOS Client" : "아이폰 OS 클라이언트",
-    "Android Client" : "안드로이드 클라이언트",
+    "Revoke" : "취소",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google 크롬",
+    "Safari" : "Safari",
+    "Google Chrome for Android" : "Android용 Google 크롬",
+    "iPhone iOS" : "iPhone iOS",
+    "iPad iOS" : "iPad iOS",
+    "iOS Client" : "iOS 클라이언트",
+    "Android Client" : "Android 클라이언트",
     "Sync client - {os}" : "동기화 클라이언트 - {os}",
     "This session" : "이 세션",
-    "Copied!" : "복사됨!",
+    "Copy" : "복사",
+    "Copied!" : "복사 성공!",
     "Not supported!" : "지원하지 않음!",
-    "Press ⌘-C to copy." : "⌘-C 복사",
-    "Press Ctrl-C to copy." : "Ctrl-C 복사",
+    "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
+    "Press Ctrl-C to copy." : "복사하려면 Ctrl-C 키를 누르십시오.",
+    "Error while loading browser sessions and device tokens" : "웹 브라우저 세션과 장치 토큰을 불러오는 중 오류가 발생했습니다",
+    "Error while creating device token" : "장치 토큰을 만드는 중 오류가 발생했습니다",
+    "Error while deleting the token" : "토큰을 삭제하는 중 오류가 발생했습니다",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "오류가 발생했습니다. ASCII로 인코딩된 PEM 인증서를 업로드하십시오.",
     "Valid until {date}" : "{date}까지 유효함",
     "Delete" : "삭제",
+    "Local" : "로컬",
+    "Private" : "개인",
+    "Only visible to local users" : "로컬 사용자만 보임",
+    "Only visible to you" : "나만 보임",
+    "Contacts" : "연락처",
+    "Visible to local users and to trusted servers" : "로컬 사용자와 신뢰된 서버에게 보이기",
+    "Public" : "공개",
+    "Will be synced to a global and public address book" : "공개 및 전역 주소록으로 동기화됨",
+    "Verify" : "확인",
+    "Verifying …" : "확인 중 …",
     "Select a profile picture" : "프로필 사진 선택",
     "Very weak password" : "매우 약한 암호",
     "Weak password" : "약한 암호",
@@ -103,28 +157,57 @@ OC.L10N.register(
     "undo" : "실행 취소",
     "never" : "없음",
     "deleted {userName}" : "{userName} 삭제됨",
+    "No user found for <strong>{pattern}</strong>" : "<strong>{pattern}</strong> 사용자를 찾을 수 없음",
+    "Unable to add user to group {group}" : "사용자를 그룹 {group}에 추가할 수 없음",
+    "Unable to remove user from group {group}" : "사용자를 그룹 {group}에서 삭제할 수 없음",
     "Add group" : "그룹 추가",
     "Invalid quota value \"{val}\"" : "잘못된 할당량 값 \"{val}\"",
     "no group" : "그룹 없음",
-    "Password successfully changed" : "암호가 성공적으로 변경되었습니다",
-    "Changing the password will result in data loss, because data recovery is not available for this user" : "이 사용자에 대해 데이터 복구를 사용할 수 없기 때문에, 암호를 변경하면 데이터를 잃게 됩니다.",
+    "Password successfully changed" : "암호를 성공적으로 변경함",
+    "Changing the password will result in data loss, because data recovery is not available for this user" : "이 사용자의 데이터를 복구할 수 없기 때문에, 암호를 변경하면 데이터가 손실됨",
+    "Could not change the users email" : "사용자 이메일을 변경할 수 없음",
+    "Error while changing status of {user}" : "{user}의 상태를 변경할 수 없음",
     "A valid username must be provided" : "올바른 사용자 이름을 입력해야 함",
     "Error creating user: {message}" : "사용자 생성 오류: {message}",
     "A valid password must be provided" : "올바른 암호를 입력해야 함",
     "A valid email must be provided" : "올바른 이메일 주소를 입력해야 함",
-    "__language_name__" : "한국어",
-    "Unlimited" : "무제한",
-    "Personal info" : "개인 정보",
-    "Sessions" : "세션",
-    "App passwords" : "앱 암호",
-    "Sync clients" : "동기화 클라이언트",
+    "Developer documentation" : "개발자 문서",
+    "View in store" : "스토어에서 보기",
+    "Limit to groups" : "그룹으로 제한",
+    "by %s" : "%s 개발",
+    "%s-licensed" : "%s 라이선스",
+    "Documentation:" : "문서:",
+    "User documentation" : "사용자 문서",
+    "Admin documentation" : "관리 문서",
+    "Visit website" : "웹 사이트 방문",
+    "Report a bug" : "버그 신고",
+    "Show description …" : "설명 보기 …",
+    "Hide description …" : "설명 숨기기 …",
+    "This app has an update available." : "이 앱을 업데이트할 수 있습니다.",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최소 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최대 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "다음 의존성을 만족할 수 없기 때문에 이 앱을 설치할 수 없습니다:",
+    "Enable only for specific groups" : "특정 그룹에만 허용",
+    "SSL Root Certificates" : "SSL 루트 인증서",
+    "Common Name" : "공통 이름",
+    "Valid until" : "만료 기간:",
+    "Issued By" : "발급자:",
+    "Valid until %s" : "%s까지 유효함",
+    "Import root certificate" : "루트 인증서 가져오기",
+    "Administrator documentation" : "관리자 문서",
+    "Online documentation" : "온라인 문서",
+    "Forum" : "포럼",
+    "Getting help" : "도움 얻기",
+    "Commercial support" : "상용 지원",
     "None" : "없음",
     "Login" : "로그인",
     "Plain" : "일반",
     "NT LAN Manager" : "NT LAN 관리자",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
     "Email server" : "이메일 서버",
     "Open documentation" : "문서 열기",
-    "This is used for sending out notifications." : "알림을 보낼 때 사용됩니다.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "암호 초기화 및 알림 이메일을 보내려면 이메일 서버를 설정해야 합니다.",
     "Send mode" : "보내기 모드",
     "Encryption" : "암호화",
     "From address" : "보낸 사람 주소",
@@ -140,9 +223,11 @@ OC.L10N.register(
     "Test email settings" : "이메일 설정 시험",
     "Send email" : "이메일 보내기",
     "Server-side encryption" : "서버 측 암호화",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "서버 측 암호화를 사용하면 이 서버에 업로드되는 파일을 암호화할 수 있습니다. 성능 감소 등 제약 사항이 있으므로 필요한 경우에만 사용하십시오.",
     "Enable server-side encryption" : "서버 측 암호화 사용",
     "Please read carefully before activating server-side encryption: " : "서버 측 암호화를 활성화하기 전에 읽어 보십시오:",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "암호화를 사용하면, 사용하기 시작한 시간 이후에 서버에 업로드된 모든 파일이 암호화됩니다. 나중에 암호화를 사용하지 않으려면 사용하고 있는 암호화 모듈에서 비활성화를 지원해야 하고 모든 사전 조건(예: 복구 키 설정)을 만족해야 합니다.",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "암호화만으로 시스템의 보안을 보장할 수 없습니다. 암호화 응용 프로그램 작동 방식 및 지원되는 사용 사례에 대한 자세한 내용은 설명서를 참조하십시오.",
     "Be aware that encryption always increases the file size." : "암호화된 파일의 크기는 항상 커집니다.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "데이터를 주기적으로 백업하는 것을 추천하며, 암호화를 사용하고 있다면 데이터와 더불어 암호화 키도 백업하십시오.",
     "This is the final warning: Do you really want to enable encryption?" : "마지막 경고입니다. 암호화를 활성화하시겠습니까?",
@@ -153,30 +238,21 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "ownCloud 8.0 이하에서 사용한 이전 암호화 키를 새 키로 이전해야 합니다.",
     "Start migration" : "이전 시작",
     "Security & setup warnings" : "보안 및 설치 경고",
-    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php가 시스템 환경 변수를 올바르게 조회할 수 있도록 설정되지 않았습니다. getenv(\"PATH\")의 값이 비어 있습니다.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "읽기 전용 설정이 활성화되었습니다. 이 상태에서는 웹 인터페이스를 통하여 일부 설정을 변경할 수 없습니다. 또한 매 업데이트마다 파일을 쓸 수 있는 상태로 변경해야 합니다.",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP에서 인라인 doc 블록을 삭제하도록 설정되어 있습니다. 일부 코어 앱에 접근할 수 없을 수도 있습니다.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Zend OPcache, eAccelerator 같은 캐시/가속기 문제일 수도 있습니다.",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP 모듈 'fileinfo'가 존재하지 않습니다. MIME 형식 감지 결과를 향상시키기 위하여 이 모듈을 활성화하는 것을 추천합니다.",
-    "System locale can not be set to a one which supports UTF-8." : "UTF-8을 지원하는 시스템 로케일을 사용할 수 없습니다.",
-    "This means that there might be problems with certain characters in file names." : "파일 이름의 일부 문자에 문제가 생길 수도 있습니다.",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "다음 중 하나 이상의 로케일을 지원하기 위하여 필요한 패키지를 시스템에 설치하는 것을 추천합니다: %s.",
-    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "도메인의 루트 디렉터리 아래에 설치되어 있지 않고 시스템 cron을 사용한다면 URL 생성에 문제가 발생할 수도 있습니다. 이 문제를 해결하려면 설치본의 웹 루트 경로에 있는 config.php 파일의 \"overwrite.cli.url\" 옵션을 변경하십시오(제안: \"%s\")",
-    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "CLI로 cronjob을 실행할 수 없었습니다. 다음 기술적 오류가 발생했습니다:",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%s\">log</a>." : "<a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">설치 가이드</a>를 ↗ 확인하고 <a href=\"%s\">로그</a>에 오류 또는 경고를 확인하시기 바랍니다.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "데이터베이스가 \"READ COMMITTED\" 트랜잭션 격리 수준에서 실행되고 있지 않습니다. 여러 작업이 동시에 실행될 때 문제가 발생할 수 있습니다.",
+    "System locale can not be set to a one which supports UTF-8." : "UTF-8을 지원하는 시스템 로캘을 사용할 수 없습니다.",
     "All checks passed." : "모든 검사를 통과했습니다.",
-    "Cron" : "Cron",
-    "Last cron job execution: %s." : "마지막 cron 작업 실행: %s.",
-    "Last cron job execution: %s. Something seems wrong." : "마지막 cron 작업 실행: %s. 문제가 발생한 것 같습니다.",
-    "Cron was not executed yet!" : "Cron이 실행되지 않았습니다!",
+    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "최적 성능을 위해서 백그라운드 작업을 올바르게 설정하는 것을 추천합니다. 큰 인스턴스에서는 'Cron'을 사용하는 것을 추천합니다. 더 많은 정보를 보려면 문서를 참조하십시오.",
     "Execute one task with each page loaded" : "개별 페이지를 불러올 때마다 실행",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php는 webcron 서비스에 등록되어 HTTP로 15분마다 cron.php에 접근합니다.",
-    "Use system's cron service to call the cron.php file every 15 minutes." : "시스템의 cron 서비스를 통하여 15분마다 cron.php 파일을 실행합니다.",
+    "The cron.php needs to be executed by the system user \"%s\"." : "시스템 사용자 \"%s\"(으)로 cron.php를 실행해야 합니다.",
     "Version" : "버전",
     "Sharing" : "공유",
+    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "관리자로 공유 행동을 미세 조정할 수 있습니다. 더 많은 정보를 보려면 문서를 참조하십시오.",
     "Allow apps to use the Share API" : "앱에서 공유 API를 사용할 수 있도록 허용",
     "Allow users to share via link" : "사용자별 링크 공유 허용",
     "Allow public uploads" : "공개 업로드 허용",
+    "Always ask for a password" : "항상 암호 묻기",
     "Enforce password protection" : "암호 보호 강제",
     "Set default expiration date" : "기본 만료 날짜 설정",
     "Expire after " : "다음 날짜 후 만료",
@@ -187,41 +263,21 @@ OC.L10N.register(
     "Restrict users to only share with users in their groups" : "그룹 내 사용자끼리만 공유할 수 있도록 허용",
     "Exclude groups from sharing" : "공유에서 그룹 제외",
     "These groups will still be able to receive shares, but not to initiate them." : "이 그룹의 사용자들은 다른 사용자가 공유한 파일을 받을 수는 있지만, 자기 파일을 공유할 수는 없습니다.",
-    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "공유 대화 상자에서 사용자 이름 자동 완성을 사용합니다. 이 설정을 사용하지 않으면 전체 사용자 이름을 입력해야 합니다.",
-    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "공개 링크 업로드 페이지에 고지 사항 텍스트를 표시합니다. (파일리스트가 숨겨져있는 경우에만 표시)",
+    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "공개 링크 업로드 페이지에 고지 사항 텍스트를 표시합니다.(파일 목록이 숨겨져 있는 경우에만 표시합니다.)",
     "This text will be shown on the public link upload page when the file list is hidden." : "파일 목록이 숨겨져 있으면 이 텍스트는 공개 링크 업로드 페이지에 표시됩니다.",
     "Tips & tricks" : "팁과 추가 정보",
+    "There are a lot of features and config switches available to optimally customize and use this instance. Here are some pointers for more information." : "이 인스턴스를 최적화하고 사용할 수 있는 여러 기능과 설정을 변경할 수 있습니다. 더 많은 정보를 보려면 여기에서 시작하십시오.",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "현재 백엔드 데이터베이스로 SQLite를 사용하고 있습니다. 대규모의 파일을 관리하려고 한다면 다른 데이터베이스 백엔드로 전환할 것을 권장합니다.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "특히 파일 동기화를 위해 데스크톱 클라이언트를 사용할 예정인 경우 권장됩니다.",
     "How to do backups" : "백업 방법",
     "Advanced monitoring" : "고급 모니터링",
     "Performance tuning" : "성능 튜닝",
     "Improving the config.php" : "config.php 개선",
     "Theming" : "테마 꾸미기",
+    "Check the security of your Nextcloud over our security scan" : "Nextcloud의 보안 상태 검사하기",
     "Hardening and security guidance" : "보안 강화 지침",
-    "Developer documentation" : "개발자 문서",
-    "%s-licensed" : "%s-라이선스",
-    "Documentation:" : "문서:",
-    "User documentation" : "사용자 문서",
-    "Admin documentation" : "관리 문서",
-    "Visit website" : "웹 사이트 방문",
-    "Report a bug" : "버그 신고",
-    "Show description …" : "설명 보기...",
-    "Hide description …" : "설명 숨기기...",
-    "This app has an update available." : "이 앱을 업데이트할 수 있습니다.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "다음 의존성을 만족할 수 없기 때문에 이 앱을 설치할 수 없습니다:",
-    "Enable only for specific groups" : "특정 그룹에만 허용",
-    "Uninstall App" : "앱 제거",
-    "SSL Root Certificates" : "SSL 루트 인증서",
-    "Common Name" : "공통 이름",
-    "Valid until" : "만료 기간:",
-    "Issued By" : "발급자:",
-    "Valid until %s" : "%s까지 유효함",
-    "Import root certificate" : "루트 인증서 가져오기",
-    "Cheers!" : "감사합니다!",
-    "Administrator documentation" : "관리자 문서",
-    "Online documentation" : "온라인 문서",
-    "Forum" : "포럼",
-    "Commercial support" : "상용 지원",
-    "You are using <strong>%s</strong> of <strong>%s</strong>" : "현재 <strong>%s</strong> / <strong>%s</strong>을(를) 사용중입니다.",
+    "You are using <strong>%s</strong> of <strong>%s</strong>" : "현재 <strong>%s</strong>/<strong>%s</strong>을(를) 사용하고 있습니다",
+    "You are using <strong>%s</strong> of <strong>%s</strong> (<strong>%s %%</strong>)" : "현재 <strong>%s</strong>/<strong>%s</strong>(<strong>%s%%</strong>)를 사용하고 있습니다",
     "Profile picture" : "프로필 사진",
     "Upload new" : "새로 업로드",
     "Select from Files" : "파일에서 선택",
@@ -235,41 +291,50 @@ OC.L10N.register(
     "Email" : "이메일",
     "Your email address" : "이메일 주소",
     "No email address set" : "이메일 주소가 설정되지 않음",
-    "For password recovery and notifications" : "암호 복구와 알림에 사용",
+    "For password reset and notifications" : "암호 초기화 및 알림에 사용",
+    "Phone number" : "휴대폰 번호",
+    "Your phone number" : "내 휴대폰 번호",
+    "Address" : "주소",
+    "Your postal address" : "내 우편 주소",
+    "Website" : "웹사이트",
+    "It can take up to 24 hours before the account is displayed as verified." : "계정이 확인된 것으로 표시될 때까지 최대 24시간이 걸릴 수 있습니다",
+    "Link https://…" : "링크 https://…",
+    "Twitter" : "트위터",
+    "Twitter handle @…" : "트위터 핸들 @…",
     "You are member of the following groups:" : "다음 그룹의 구성원입니다:",
+    "Language" : "언어",
+    "Help translate" : "번역 돕기",
     "Password" : "암호",
     "Current password" : "현재 암호",
     "New password" : "새 암호",
     "Change password" : "암호 변경",
-    "Language" : "언어",
-    "Help translate" : "번역 돕기",
-    "Get the apps to sync your files" : "파일 동기화 앱 가져오기",
-    "Desktop client" : "데스크톱 클라이언트",
-    "Android app" : "Android 앱",
-    "iOS app" : "iOS 앱",
-    "Show First Run Wizard again" : "첫 실행 마법사 다시 보이기",
+    "Web, desktop and mobile clients currently logged in to your account." : "사용자 계정으로 로그인된 웹, 데스크톱, 모바일 클라이언트 목록입니다.",
     "Device" : "장치",
     "Last activity" : "최근 활동",
-    "Name" : "이름",
     "App name" : "앱 이름",
     "Create new app password" : "새로운 앱 암호 만들기",
     "Use the credentials below to configure your app or device." : "앱 또는 장치를 구성하는 아래의 자격 증명을 사용합니다.",
     "For security reasons this password will only be shown once." : "보안상의 이유로 이 암호는 한 번만 표시됩니다.",
     "Username" : "사용자 이름",
     "Done" : "완료",
+    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{communityopen}Nextcloud 커뮤니티{linkclose}에서 개발, {githubopen}소스 코드{linkclose}는 {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} 라이선스를 따릅니다.",
+    "Settings" : "설정",
     "Show storage location" : "저장소 위치 보이기",
-    "Show last log in" : "마지막 로그인 시간 보이기",
     "Show user backend" : "사용자 백엔드 보이기",
-    "Send email to new user" : "새 사용자에게 이메일 보내기",
+    "Show last login" : "마지막 로그인 보이기",
     "Show email address" : "이메일 주소 보이기",
+    "Send email to new user" : "새 사용자에게 이메일 보내기",
+    "When the password of a new user is left empty, an activation email with a link to set the password is sent." : "새 사용자의 암호가 비어 있으면 암호를 설정하는 링크가 포함된 활성화 이메일을 보냅니다다.",
     "E-Mail" : "이메일",
     "Create" : "만들기",
     "Admin Recovery Password" : "관리자 복구 암호",
     "Enter the recovery password in order to recover the users files during password change" : "암호 변경 시 변경된 사용자 파일을 복구하려면 복구 암호를 입력하십시오",
     "Everyone" : "모두",
     "Admins" : "관리자",
+    "Disabled" : "비활성화됨",
     "Default quota" : "기본 할당량",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "저장소 할당량을 입력하십시오 (예: \"512 MB\", \"12 GB\")",
+    "Unlimited" : "무제한",
     "Other" : "기타",
     "Group admin for" : "다음 그룹의 관리자:",
     "Quota" : "할당량",
@@ -280,43 +345,74 @@ OC.L10N.register(
     "set new password" : "새 암호 설정",
     "change email address" : "이메일 주소 변경",
     "Default" : "기본값",
-    "log-level out of allowed range" : "로그 단계가 허용 범위를 벗어남",
-    "Language changed" : "언어가 변경됨",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "신뢰할 수 있는 도메인 목록에 \"{domain}\"을(를) 추가하시겠습니까?",
-    "iPhone" : "아이폰",
-    "add group" : "그룹 추가",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "모두 (치명적 문제, 오류, 경고, 정보, 디버그)",
-    "Info, warnings, errors and fatal issues" : "정보, 경고, 오류, 치명적 문제",
-    "Warnings, errors and fatal issues" : "경고, 오류, 치명적 문제",
-    "Errors and fatal issues" : "오류, 치명적 문제",
-    "Fatal issues only" : "치명적 문제만",
-    "Log" : "로그",
-    "What to log" : "남길 로그",
-    "Download logfile" : "로그 파일 다운로드",
-    "More" : "더 중요함",
-    "Less" : "덜 중요함",
-    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "로그 파일이 100MB보다 큽니다. 다운로드하는 데 시간이 걸릴 수 있습니다!",
-    "Allow users to send mail notification for shared files" : "공유 파일 이메일 알림 전송 허용",
-    "Allow users to send mail notification for shared files to other users" : "다른 사용자에게 공유 파일 이메일 알림 전송 허용",
-    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "데이터베이스로 SQLite를 사용하고 있습니다. 대규모의 파일을 관리하려고 한다면 다른 데이터베이스 백엔드로 전환할 것을 권장합니다.",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "특히 파일 동기화를 위해 데스크톱 클라이언트를 사용할 예정이면, SQLite를 사용하지 않는 것이 좋습니다.",
-    "Experimental applications ahead" : "실험적인 앱 사용 예정",
-    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "실험적인 앱은 보안 문제 검사를 통과하지 않았으며, 아직 새롭거나, 불안정하거나, 개발 중일 수도 있습니다. 이러한 앱을 설치하면 데이터 손실 및 보안 문제가 발생할 수도 있습니다.",
-    "Enable experimental apps" : "실험적인 앱 사용",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "안녕하세요.<br><br>%s 계정을 사용할 수 있음을 알려 드립니다.<br><br>사용자 이름: %s<br>접근 링크: <a href=\"%s\">%s</a><br><br>",
-    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "안녕하세요.\n\n%s 계정을 사용할 수 있음을 알려 드립니다.\n\n사용자 이름: %s\n접근 링크: %s\n\n",
-    "Add Group" : "그룹 추가",
-    "Group" : "그룹",
-    "Default Quota" : "기본 할당량",
-    "Full Name" : "전체 이름",
-    "Group Admin for" : "다음 그룹의 관리자:",
-    "Storage Location" : "저장소 위치",
-    "User Backend" : "사용자 백엔드",
-    "Last Login" : "마지막 로그인",
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "External Storage" : "외부 저장소",
-    "Updates" : "업데이트",
-    "An error occurred: {message}" : "오류 발생: {message}"
+    "Enabled" : "활성",
+    "Not enabled" : "비활성",
+    "Please provide an admin recovery password, otherwise all user data will be lost" : "관리자 복구 암호를 입력하지 않으면 모든 사용자 데이터가 삭제됩니다",
+    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "백엔드에서 암호 변경을 지원하지 않지만, 암호화 키는 갱신되었습니다.",
+    "test email settings" : "이메일 설정 시험",
+    "Invalid request" : "잘못된 요청",
+    "Admins can't remove themself from the admin group" : "관리자 자신을 관리자 그룹에서 삭제할 수 없음",
+    "Unable to add user to group %s" : "그룹 %s에 사용자를 추가할 수 없음",
+    "Unable to remove user from group %s" : "그룹 %s에서 사용자를 삭제할 수 없음",
+    "Sending..." : "보내는 중...",
+    "_You have %n app update pending_::_You have %n app updates pending_" : ["앱 %n개 업데이트 대기 중"],
+    "Uninstalling ...." : "제거하는 중 ....",
+    "Error while uninstalling app" : "앱을 제거하는 중 오류 발생",
+    "Uninstall" : "제거",
+    "__language_name__" : "한국어",
+    "Personal info" : "개인 정보",
+    "Sessions" : "세션",
+    "App passwords" : "앱 암호",
+    "Sync clients" : "동기화 클라이언트",
+    "This is used for sending out notifications." : "알림을 보낼 때 사용합니다.",
+    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php가 시스템 환경 변수를 올바르게 조회할 수 있도록 설정되지 않았습니다. getenv(\"PATH\")의 값이 비어 있습니다.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "서버 PHP 설정(특히 php-fpm 사용 시)에 관한 내용은 <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">설치 가이드 ↗</a>를 참고하십시오.",
+    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP에서 인라인 doc 블록을 삭제하도록 설정되어 있습니다. 일부 코어 앱에 접근할 수 없을 수도 있습니다.",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s의 버전 %2$s 미만이 설치되어 있습니다. 안정성과 성능을 위해 %1$s의 새로운 버전으로 업데이트하는 것을 권장합니다.",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP의 'fileinfo' 모듈이 없습니다. 올바른 MIME 형식 감지를 위해서 이 모듈을 활성화하는 것을 추천합니다.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "트랜잭션 파일 잠금이 비활성화되어있어 동시 접근 시 문제가 발생할 수 있습니다. config.php에서 'filelocking.enabled'를 활성화하여 이 문제를 해결할 수 있습니다. 자세한 내용은 <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">사용 설명서 ↗</a>를 참고하십시오.",
+    "This means that there might be problems with certain characters in file names." : "파일 이름의 일부 문자에 문제가 생길 수도 있습니다.",
+    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "다음 중 하나 이상의 로캘을 지원하기 위하여 필요한 패키지를 시스템에 설치하는 것을 추천합니다: %s.",
+    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "도메인의 루트 디렉터리 아래에 설치되어 있지 않고 시스템 cron을 사용한다면 URL 생성에 문제가 발생할 수도 있습니다. 이 문제를 해결하려면 설치본의 웹 루트 경로에 있는 config.php 파일의 \"overwrite.cli.url\" 옵션을 변경하십시오(제안: \"%s\")",
+    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "CLI로 cronjob을 실행할 수 없었습니다. 다음 기술적 오류가 발생했습니다:",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%s\">log</a>." : "<a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">설치 가이드 ↗</a>를 확인하고 <a href=\"%s\">로그</a>의 오류 또는 경고를 확인하십시오.",
+    "Cron" : "Cron",
+    "Last cron job execution: %s." : "마지막 cron 작업 실행: %s.",
+    "Last cron job execution: %s. Something seems wrong." : "마지막 cron 작업 실행: %s. 문제가 발생한 것 같습니다.",
+    "Cron was not executed yet!" : "Cron이 실행되지 않았습니다!",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php는 webcron 서비스에 등록되어 HTTP로 15분마다 cron.php에 접근합니다.",
+    "Use system's cron service to call the cron.php file every 15 minutes." : "시스템의 cron 서비스를 통하여 15분마다 cron.php 파일을 실행합니다.",
+    "To run this you need the PHP posix extension. See {linkstart}PHP documentation{linkend} for more details." : "실행하려면 PHP POSIX 확장이 필요합니다. 자세한 내용은 {linkstart}PHP 사용 설명서{linkend}를 참고하십시오.",
+    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "공유 대화 상자에서 사용자 이름 자동 완성을 사용합니다. 이 설정을 사용하지 않으면 전체 사용자 이름을 입력해야 합니다.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "다른 데이터베이스로 마이그레이션하려면 'occ db:convert-type' 명령행 도구를 사용하거나 <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">사용 설명서 ↗</a>를 참고하십시오.",
+    "Uninstall app" : "앱 삭제",
+    "Hey there,<br><br>just letting you know that you now have a %s account.<br><br>Your username: <strong>%s</strong><br>Access it: <strong><a href=\"%s\">%s</a></strong><br><br>" : "안녕하세요.<br><br>%s 계정을 사용할 수 있음을 알려 드립니다.<br><br>사용자 이름: <strong>%s</strong><br>접근 링크: <strong><a href=\"%s\">%s</a></strong><br><br>",
+    "Cheers!" : "감사합니다!",
+    "Hey there,\n\njust letting you know that you now have a %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "안녕하세요.\n\n%s 계정을 사용할 수 있음을 알려 드립니다.\n\n사용자 이름: %s\n접근 링크: %s\n\n",
+    "For password recovery and notifications" : "암호 복구와 알림에 사용",
+    "Your website" : "내 웹 사이트",
+    "Your Twitter handle" : "내 트위터",
+    "Get the apps to sync your files" : "파일 동기화 앱 가져오기",
+    "Desktop client" : "데스크톱 클라이언트",
+    "Android app" : "Android 앱",
+    "iOS app" : "iOS 앱",
+    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "이 프로젝트를 지원하려면 {contributeopen}개발에 참여{linkclose}하거나 {contributeopen}주변에 알려 주세요{linkclose}!",
+    "Show First Run Wizard again" : "첫 실행 마법사 다시 보이기",
+    "Passcodes that give an app or device permissions to access your account." : "앱 암호는 앱이나 장치가 사용자 계정에 접근할 수 있도록 해줍니다.",
+    "Name" : "이름",
+    "Follow us on Google Plus!" : "Google Plus를 팔로우하세요!",
+    "Like our facebook page!" : "Facebook 페이지에서 좋아요를 눌러 주세요!",
+    "Subscribe to our twitter channel!" : "Twitter 채널을 구독하세요!",
+    "Subscribe to our news feed!" : "뉴스 피드를 구독하세요!",
+    "Subscribe to our newsletter!" : "뉴스레터를 구독하세요!",
+    "Show last log in" : "마지막 로그인 시간 보이기",
+    "Group name" : "그룹 이름",
+    "Verifying" : "확인 중",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the Tips & Ticks section and the documentation for more information." : "내 인스턴스가 올바르게 설정되어 있어야 시스템 보안과 성능을 보장할 수 있습니다. 설정 확인을 돕기 위해서 일부 항목을 자동으로 확인합니다. 더 많은 정보를 보려면 문서의 팁과 추가 정보 장을 참조하십시오.",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with MIME type detection." : "PHP의 'fileinfo' 모듈이 없습니다. 올바른 MIME 형식 감지를 위해서 이 모듈을 활성화하는 것을 추천합니다.",
+    "Here you can generate individual passwords for apps so you don’t have to give out your password. You can revoke them individually too." : "앱 암호를 생성하여 내 암호를 공개하지 않아도 됩니다. 이 암호는 개별적으로 폐기할 수도 있습니다.",
+    "Follow us on Google+!" : "Google+에서 저희를 팔로하세요!",
+    "Follow us on Twitter!" : "트위터에서 저희를 팔로하세요!",
+    "Check out our blog!" : "블로그를 확인해 보세요!"
 },
 "nplurals=1; plural=0;");
